@@ -22,12 +22,12 @@
 #include "wordlist.h"
 
 #include <QCheckBox>
-#include <QLocale>
 #include <QGridLayout>
+#include <QLocale>
 #include <QProgressDialog>
 #include <QSpinBox>
 #include <QStandardPaths>
-#include <QTextCodec>
+#include <QStringConverter>
 
 #include <QDebug>
 
@@ -55,17 +55,16 @@ void CreationSourceWidget::emptyToggled(bool checked)
 }
 
 DictionaryCreationWizard::DictionaryCreationWizard(QWidget *parent,
-        const QStringList &dictionaryNames, const QStringList &dictionaryFiles,
-        const QStringList &dictionaryLanguages)
+                                                   const QStringList &dictionaryNames,
+                                                   const QStringList &dictionaryFiles,
+                                                   const QStringList &dictionaryLanguages)
     : QWizard(parent)
 {
-    buildCodecList();
-
     creationSource = new CreationSourceWidget(this, QStringLiteral("source page"));
     creationSource->setTitle(i18n("Source of New Dictionary (1)"));
     setPage(CreationSourcePage, creationSource);
     setOption(QWizard::HaveHelpButton, false);
-    //setFinishEnabled (creationSource, false);
+    // setFinishEnabled (creationSource, false);
 
     fileWidget = new CreationSourceDetailsWidget(this, QStringLiteral("file source page"));
     fileWidget->setTitle(i18n("Source of New Dictionary (2)"));
@@ -98,29 +97,14 @@ DictionaryCreationWizard::DictionaryCreationWizard(QWidget *parent,
 
 DictionaryCreationWizard::~DictionaryCreationWizard()
 {
-    delete codecList;
-}
-
-void DictionaryCreationWizard::buildCodecList()
-{
-    codecList = new QList<QTextCodec*>;
-    QList<QByteArray> availableCodecs = QTextCodec::availableCodecs();
-    for (int i = 0; i < availableCodecs.count(); ++i) {
-        QTextCodec *codec = QTextCodec::codecForName(availableCodecs[i]);
-        codecList->append(codec);
-    }
 }
 
 void DictionaryCreationWizard::buildCodecCombo(KComboBox *combo)
 {
-    QString local = i18nc("Local characterset", "Local") + QStringLiteral(" (");
-    local += QLatin1String(QTextCodec::codecForLocale()->name()) + QLatin1Char(')');
-    combo->addItem(local, 0);
-    combo->addItem(i18nc("Latin characterset", "Latin1"), 1);
-    combo->addItem(i18n("Unicode"), 2);
-
-    for (int i = 0; i < codecList->count(); i++)
-        combo->addItem(QLatin1String(codecList->at(i)->name()), i + 3);
+    for (int encoding = QStringConverter::System; encoding <= QStringConverter::System; ++encoding) {
+        QString name = QLatin1String(QStringConverter::nameForEncoding(QStringConverter::Encoding(encoding)));
+        combo->addItem(name, encoding);
+    }
 }
 
 QString DictionaryCreationWizard::createDictionary()
@@ -136,40 +120,16 @@ QString DictionaryCreationWizard::createDictionary()
         dicFile.clear();
     } else if (creationSource->fileButton->isChecked()) {
         QString filename = fileWidget->url->url().path();
-        int encoding = fileWidget->encodingCombo->currentIndex();
+        QStringConverter::Encoding encoding = QStringConverter::Encoding(fileWidget->encodingCombo->currentIndex());
         if (fileWidget->spellCheckBox->isChecked())
             dicFile = fileWidget->ooDictURL->url().path();
-        switch (encoding) {
-        case 0:
-            map = WordList::parseFile(filename, QTextCodec::codecForLocale(), pdlg);
-            break;
-        case 1:
-            map = WordList::parseFile(filename, QTextCodec::codecForName("ISO-8859-1"), pdlg);
-            break;
-        case 2:
-            map = WordList::parseFile(filename, QTextCodec::codecForName("UTF-16"), pdlg);
-            break;
-        default:
-            map = WordList::parseFile(filename, codecList->at(encoding - 3), pdlg);
-        }
+        map = WordList::parseFile(filename, encoding, pdlg);
     } else if (creationSource->directoryButton->isChecked()) {
         QString directory = dirWidget->url->url().path();
-        int encoding = dirWidget->encodingCombo->currentIndex();
+        QStringConverter::Encoding encoding = QStringConverter::Encoding(fileWidget->encodingCombo->currentIndex());
         if (dirWidget->spellCheckBox->isChecked())
             dicFile = dirWidget->ooDictURL->url().path();
-        switch (encoding) {
-        case 0:
-            map = WordList::parseDir(directory, QTextCodec::codecForLocale(), pdlg);
-            break;
-        case 1:
-            map = WordList::parseDir(directory, QTextCodec::codecForName("ISO-8859-1"), pdlg);
-            break;
-        case 2:
-            map = WordList::parseDir(directory, QTextCodec::codecForName("UTF-16"), pdlg);
-            break;
-        default:
-            map = WordList::parseDir(directory, codecList->at(encoding - 3), pdlg);
-        }
+        map = WordList::parseDir(directory, encoding, pdlg);
     } else { // creationSource->kdeDocButton must be checked
         QString language = kdeDocWidget->languageButton->current();
         if (kdeDocWidget->spellCheckBox->isChecked())
@@ -230,11 +190,9 @@ QString DictionaryCreationWizard::language()
 
 /***************************************************************************/
 
-MergeWidget::MergeWidget(QWidget *parent,
-                         const QStringList &dictionaryNames, const QStringList &dictionaryFiles,
-                         const QStringList &dictionaryLanguages)
-    : QWizardPage(parent),
-      scrollArea(nullptr)
+MergeWidget::MergeWidget(QWidget *parent, const QStringList &dictionaryNames, const QStringList &dictionaryFiles, const QStringList &dictionaryLanguages)
+    : QWizardPage(parent)
+    , scrollArea(nullptr)
 {
     QGridLayout *layout = new QGridLayout(this);
     layout->setColumnStretch(0, 0);
@@ -258,7 +216,7 @@ MergeWidget::MergeWidget(QWidget *parent,
 
         dictionaries.insert(*fIt, checkbox);
         weights.insert(*fIt, spinBox);
-        languages [*fIt] = *lIt;
+        languages[*fIt] = *lIt;
         row++;
     }
     setLayout(layout);
@@ -268,10 +226,10 @@ MergeWidget::~MergeWidget()
 {
 }
 
-QMap <QString, int> MergeWidget::mergeParameters()
+QMap<QString, int> MergeWidget::mergeParameters()
 {
-    QMap <QString, int> files;
-    QHashIterator<QString, QCheckBox*> it(dictionaries);
+    QMap<QString, int> files;
+    QHashIterator<QString, QCheckBox *> it(dictionaries);
     while (it.hasNext()) {
         it.next();
         if (it.value()->isChecked()) {
@@ -286,11 +244,11 @@ QMap <QString, int> MergeWidget::mergeParameters()
 
 QString MergeWidget::language()
 {
-    QHashIterator<QString, QCheckBox*> it(dictionaries);
+    QHashIterator<QString, QCheckBox *> it(dictionaries);
     while (it.hasNext()) {
         it.next();
         if (it.value()->isChecked()) {
-            return languages [it.key()];
+            return languages[it.key()];
         }
     }
 
@@ -331,11 +289,10 @@ void CompletionWizardWidget::ok()
     dictionaryFile = QStandardPaths::writableLocation(QStandardPaths::AppDataLocation) + QLatin1Char('/') + QStringLiteral("/");
     qDebug() << "dictionaryFile is " << dictionaryFile;
     if (WordList::saveWordList(map, dictionaryFile)) {
-        KConfigGroup cg(KSharedConfig::openConfig(), "Dictionary 0");
+        KConfigGroup cg(KSharedConfig::openConfig(), QStringLiteral("Dictionary 0"));
         cg.writeEntry("Filename", "wordcompletion1.dict");
-        cg.writeEntry("Name",     i18nc("Default dictionary", "Default"));
+        cg.writeEntry("Name", i18nc("Default dictionary", "Default"));
         cg.writeEntry("Language", language);
         cg.sync();
     }
 }
-
